﻿using Prism.Commands;
using Prism.Mvvm;
using Prism.Navigation;
using Syncfusion.DataSource;
using Syncfusion.ListView.XForms;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Reflection;
using System.Runtime.CompilerServices;
using Xamarin.Forms;

namespace ListViewPrism
{
    public class MainPageViewModel : BindableBase, INavigationAware
    {
        #region Properties
        public ObservableCollection<Contacts> ContactsInfo { get; set; }
        public Command<object> ResetSwipeCommand
        {
            get { return resetSwipeCommand; }
            protected set { resetSwipeCommand = value; }
        }
        
        public Command<object> SwipeEndedCommand
        {
            get { return swipeCommand; }
            protected set { swipeCommand = value; }
        }
        public Command<object> SwipeRightCommand { get; set; }
        public SfListView ListView { get; set; }

        #endregion

        #region Constructor

        public MainPageViewModel()
        {
            ContactsInfo = new ObservableCollection<Contacts>();

            SwipeEndedCommand = new Command<object>(OnSwipeEnded);
            SwipeRightCommand = new Command<object>(OnSwipeRight);
            ResetSwipeCommand = new Command<object>(OnResetSwipeCommand);

            Random r = new Random();
            Assembly assembly = typeof(MainPage).GetTypeInfo().Assembly;

            foreach (var cusName in CustomerNames)
            {
                var contact = new Contacts(cusName, r.Next(720, 799).ToString() + " - " + r.Next(3010, 3999).ToString());
                contact.ContactImage = ImageSource.FromResource("ListViewPrism.Images.Image" + r.Next(0, 28) + ".png", assembly);
                contact.ContactColor = Color.FromRgb(r.Next(40, 255), r.Next(40, 255), r.Next(40, 255));
                ContactsInfo.Add(contact);
            }
        }

        #endregion


        #region Private Methods

        private void OnResetSwipeCommand(object obj)
        {
            var listview = obj as SfListView;
            listview.ResetSwipe();
        }

        private void OnSwipeEnded(object obj)
        {

            //you can also use below listview to resetswipe 
            //  swipeArgs.ListView.ResetSwipe();
        }

        private void OnSwipeRight(object obj)
        {
            var swipedItem = obj as Contacts;
            App.Current.MainPage.DisplayAlert("Message", "Item deleted in right swipe : " + swipedItem.ContactName, "Ok");
            this.ContactsInfo.Remove(swipedItem);
        }

        #endregion

        #region Fields

        string[] CustomerNames = new string[] {
            "Kyle",
            "Gina",
            "Irene",
            "Katie",
            "Michael",
            "Oscar",
            "Ralph",
            "Torrey",
            "William",
            "Bill",
            "Daniel",
            "Frank",
            "Brenda",
            "Danielle",
            "Fiona",
            "Howard",
            "Jack",
            "Larry",
            "Holly",
            "Jennifer",
            "Liz",
            "Pete",
            "Steve",
            "Vince",
            "Zeke",
            "Aiden",
            "Jackson"    ,
            "Mason  "    ,
            "Liam   "    ,
            "Jacob  "    ,
            "Jayden "    ,
            "Ethan  "    ,
            "Noah   "    ,
            "Lucas  "    ,
            "Logan  "    ,
            "Caleb  "    ,
            "Caden  "    ,
            "Jack   "    ,
            "Ryan   "    ,
            "Connor "    ,
            "Michael"    ,
            "Elijah "    ,
            "Brayden"    ,
            "Benjamin"   ,
            "Nicholas"   ,
            "Alexander"  ,
            "William"    ,
            "Matthew"    ,
            "James  "    ,
            "Landon "    ,
            "Nathan "    ,
            "Dylan  "    ,
            "Evan   "    ,
            "Luke   "    ,
            "Andrew "    ,
            "Gabriel"    ,
            "Gavin  "    ,
            "Joshua "    ,
            "Owen   "    ,
            "Daniel "    ,
            "Carter "    ,
            "Tyler  "    ,
            "Cameron"    ,
            "Christian"  ,
            "Wyatt  "    ,
            "Henry  "    ,
            "Eli    "    ,
            "Joseph "    ,
            "Max    "    ,
            "Isaac  "    ,
            "Samuel "    ,
            "Anthony"    ,
            "Grayson"    ,
            "Zachary"    ,
            "David  "    ,
            "Christopher",
            "John   "    ,
            "Isaiah "    ,
            "Levi   "    ,
            "Jonathan"   ,
            "Oliver "    ,
            "Chase  "    ,
            "Cooper "    ,
            "Tristan"    ,
            "Colton "    ,
            "Austin "    ,
            "Colin  "    ,
            "Charlie"    ,
            "Dominic"    ,
            "Parker "    ,
            "Hunter "    ,
            "Thomas "    ,
            "Alex   "    ,
            "Ian    "    ,
            "Jordan "    ,
            "Cole   "    ,
            "Julian "    ,
            "Aaron  "    ,
            "Carson "    ,
            "Miles  "    ,
            "Blake  "    ,
            "Brody  "    ,
            "Adam   "    ,
            "Sebastian"  ,
            "Adrian "    ,
            "Nolan  "    ,
            "Sean   "    ,
            "Riley  "    ,
            "Bentley"    ,
            "Xavier "    ,
            "Hayden "    ,
            "Jeremiah"   ,
            "Jason  "    ,
            "Jake   "    ,
            "Asher  "    ,
            "Micah  "    ,
            "Jace   "    ,
            "Brandon"    ,
            "Josiah "    ,
            "Hudson "    ,
            "Nathaniel"  ,
            "Bryson "    ,
            "Ryder  "    ,
            "Justin "    ,
            "Bryce  "    ,
        };
        private Command<object> swipeCommand;
        private Command<object> resetSwipeCommand;

        #endregion

        #region Prism Methods

        public void OnNavigatedFrom(INavigationParameters parameters)
        {

        }

        public void OnNavigatedTo(INavigationParameters parameters)
        {
        }

        public void OnNavigatingTo(INavigationParameters parameters)
        {

        }
        #endregion
    }
}
